import React, { useEffect, useState } from "react";
import "./homstyle.css";
import axios from "axios";

const Home = () => {
  const [data, setData] = useState({
    celsius: 10,
    name: "Thrissur",
    humidity: 10,
    speed: 2,
    image: '/images/cloudy.png'
  });

  const [name, setName] = useState('');
  const [error, setError] = useState('');

  const handleClick = () => {
    if (name !== "") {
      const apiUrl = `https://api.openweathermap.org/data/2.5/weather?q=${name}&appid=13a0338f8c35fbc25d9984555656ee23&units=metric`;
      axios.get(apiUrl)
        .then((result) => {
          console.log(result.data);

            let imagePath = '';
            
            if (result.data.weather[0].main == "Clouds") {
              imagePath = "/images/cloudy.png";              
            } else if (result.data.weather[0].main == "Clear") {
              imagePath = "/images/clear.png";           
            } else if (result.data.weather[0].main == "Rain") {
              imagePath = "/images/rain.png";
            }else if (result.data.weather[0].main == "Drizzle") {
              imagePath = "/images/drizzle.png";
            } else if (result.data.weather[0].main == "Mist") {
              imagePath = "/images/mist.png";
            }else {
              imagePath = "/images/cloudy.png";
            }

          setData({
            ...data,
            celsius: result.data.main.temp,
            name: result.data.name,
            humidity: result.data.main.humidity,
            speed: result.data.wind.speed,
            image: imagePath
          })
          setError('');
          console.log(result.data);
        })
        .catch((err) => {
          if (err.response.status == 404) {
            setError("Invalid City Name");            
          } else {
            setError('');
          }
          console.log(err);
        });
    }
  }
  return (
    <div className="container">
      <div className="weather">
        <div className="search">
          <input
            type="text"
            name=""
            placeholder="Enter City Name"
            onChange={(e) => setName(e.target.value)}
          />
          <button>
            <img
              src="images/loupe.png"
              alt="search"
              className="searchImg"
              onClick={handleClick}
            />
          </button>
        </div>
        <div className="error">
          <p>{error}</p>
        </div>
        <div className="winfo">
          <img src={data.image} alt="clouds sun" className="cloudImg" />
          <h1>{Math.round(data.celsius)}°C</h1>
          <h2>{data.name}</h2>
        </div>
        <div className="details">
          <div className="col">
            <img
              src="images/humidity.png"
              alt="humidity 3 drops"
              className="colImg"
            />
            <div className="humidity">
              <p>{Math.round(data.humidity)} %</p>
              <p>Humidity</p>
            </div>
          </div>
          <div className="col">
            <img
              src="images/wind.png"
              alt="wind shake trees"
              className="colImg"
            />
            <div className="wind">
              <p>{Math.round(data.speed)} km/hr</p>
              <p>Wind</p>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Home;
